#
# spec file for package golang
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         golang
%global repo            net
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     golang.org/x/net

Name:           golang-org-x-%{repo}-context
Version:        1.12+git20190812.cdfb69a
Release:        lp152.1.1
Summary:        Context defines the Context type
License:        BSD-3-Clause
Group:          Development/Languages/Golang
Url:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.xz
Source1:        rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

BuildRequires:  golang-packaging
BuildRequires:  xz

%{go_provides}

%description
Package context defines the Context type, which carries deadlines, cancelation signals, and other request-scoped values across API boundaries and between processes.

%prep
%setup -q -n %{repo}-%{version}
rm -rf $(find * -type d | grep -v '^context')

%build
%goprep %{import_path}
%gobuild ./context

%install
%goinstall
%gosrc
%gofilelist

%check
%gotest %{import_path}/context

%files -f file.lst
%defattr(-,root,root,-)
%doc AUTHORS CONTRIBUTORS PATENTS README.md
%license LICENSE

%changelog
* Tue Nov  5 2019 mrostecki@opensuse.org
- Update to version 1.12+git20190812.cdfb69a:
  * [release-branch.go1.12] http2: limit number of control frames in server send queue
  * http2/h2demo: fix the HTTP/1-vs-HTTP/2 demo after HSTS breakage
  * html: update inSelectIM and inSelectInTableIM for the latest spec
  * html: make (*nodeStack)contains distinguish namespace
  * http2: Revert a closed stream cannot receive data
  * trace: tighten the check for duplicate registration
  * route: update package docs
  * route: fix TestRouteMessage
  * proxy: support socks5h scheme in proxy URL
  * ipv4, ipv6: directly initialize ctlOpts and sockOpts
* Wed May 15 2019 mrostecki@opensuse.org
- Update to version 1.11+git20190403.48a9fcb:
  * route: don't run NET_RT_IFLIST vs. NET_RT_IFLISTL test in 386
    emulation (again)
  * route: re-adjust routing message alignment for FreeBSD 386
    emulation
  * http2: don't leak streams on broken body
  * html: don't ignore token when current token is not <template>
  * icmp: clarify the format used by raw ICMP socket
  * ipv4: clarify the format used by raw IP socket
  * publicsuffix: update table to latest list from publicsuffix.org
  * trace: better error message for double init
  * http2/hpack: lazily build huffman table on first use
  * http2/hpack: reduce memory for huffman decoding table
* Fri Jun  2 2017 thipp@suse.de
- Use full tarball and include %%doc section
* Fri Apr 28 2017 opensuse-packaging@opensuse.org
- Update to version 0.0.0+git20170424.da118f7:
  * context/ctxhttp: remove pre-Go 1.5 support
  * context: fix doc typo
  * context: correct spelling of TODO in comment
  * context/ctxhttp: add a specialized minimal version for Go 1.7
  * context/ctxhttp: if context is canceled, return its error
  * context: use Go 1.8 type alias for CancelFunc and Context
  * Revert "context: use Go 1.8 type alias for CancelFunc and Context"
  * context: deflake tests under Go 1.6
  * all: single space after period
  * context/ctxhttp: close httptest server
* Fri Apr 28 2017 jmassaguerpla@suse.com
- Only package and build golang.org/x/net/websocketto prevent problems with
  build requirements of golang.org/x/net
* Tue Feb 28 2017 thipp@suse.de
- Update to version 1.5.2+git20170227.906cda9:
  * publicsuffix: update table to latest list from publicsuffix.org
  * internal/netreflect: don't build on go1.9 or above
  * lif: drop support for go1.5
  * route: drop support for go1.5
  * ipv4, ipv6, internal/netreflect, bpf: fix the x/net build
  * http2/hpack: remove hpack's constant time string comparison
  * http2: replace fixedBuffer with dataBuffer
  * http2: Add opt-in option to Framer to allow DataFrame struct reuse
  * http2/hpack: speedup Encoder.searchTable
  * http2: add configurable knobs for the server's receive window
* Mon Feb 27 2017 thipp@suse.de
- Initial commit
- Add _service
- Add rpmlintrc
